@@ -6,7 +6,7 @@
 
 #include "contactprintthemeconfiguredialog.h"
 #include "contactprintthemeeditorutil.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <TextCustomEditor/PlainTextEditorWidget>
 
 #include "configurewidget.h"
 
@@ -43,12 +43,12 @@ ContactPrintThemeConfigureDialog::ContactPrintThemeConfigureDialog(QWidget *pare
     auto lab = new QLabel(i18n("Default contact:"));
     lay->addWidget(lab);
 
-    mDefaultContact = new ContactEditor::AkonadiContactEditor(ContactEditor::AkonadiContactEditor::CreateMode, ContactEditor::AkonadiContactEditor::VCardMode);
+    mDefaultContact = new Akonadi::AkonadiContactEditor(Akonadi::AkonadiContactEditor::CreateMode, Akonadi::AkonadiContactEditor::VCardMode);
     lay->addWidget(mDefaultContact);
 
     tab->addTab(w, i18n("General"));
 
-    mDefaultTemplate = new KPIMTextEdit::PlainTextEditorWidget;
+    mDefaultTemplate = new TextCustomEditor::PlainTextEditorWidget;
     tab->addTab(mDefaultTemplate, i18n("Default Template"));
 
     auto mainLayout = new QVBoxLayout(this);
@@ -125,7 +125,7 @@ void ContactPrintThemeConfigureDialog::readConfig()
 
     mConfigureWidget->readConfig();
 
-    KConfigGroup group = KConfigGroup(config, "ContactPrintThemeConfigureDialog");
+    KConfigGroup group = KConfigGroup(config, QStringLiteral("ContactPrintThemeConfigureDialog"));
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -144,3 +144,5 @@ void ContactPrintThemeConfigureDialog::writeConfig()
     group.writeEntry("defaultTemplate", mDefaultTemplate->toPlainText());
     mConfigureWidget->writeConfig();
 }
+
+#include "moc_contactprintthemeconfiguredialog.cpp"
