@@ -12,7 +12,7 @@
 #include "previewwidget.h"
 #include "themeeditorwidget.h"
 #include "themetemplatewidget.h"
-#include <KPIMTextEdit/PlainTextEditor>
+#include <TextCustomEditor/PlainTextEditor>
 
 #include <KLocalizedString>
 
@@ -61,7 +61,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
     connect(mEditor->editor(), &QPlainTextEdit::textChanged, this, &GrantleeThemeEditor::EditorPage::changed);
 
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
         const QList<int> size{400, 100};
         mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
         mWidgetSplitter->setSizes(group.readEntry("widgetSplitter", size));
@@ -71,7 +71,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 EditorPage::~EditorPage()
 {
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
         group.writeEntry("mainSplitter", mMainSplitter->sizes());
         group.writeEntry("widgetSplitter", mWidgetSplitter->sizes());
     }
@@ -81,3 +81,5 @@ ContactPrintThemePreview *EditorPage::preview() const
 {
     return mPreview;
 }
+
+#include "moc_editorpage.cpp"
