@@ -10,7 +10,7 @@
 using namespace GrantleeThemeEditor;
 
 EditorWidget::EditorWidget(QWidget *parent)
-    : KPIMTextEdit::PlainTextEditorWidget(new GrantleeThemeEditor::GrantleePlainTextEditor(), parent)
+    : TextCustomEditor::PlainTextEditorWidget(new GrantleeThemeEditor::GrantleePlainTextEditor(), parent)
 {
 }
 
@@ -48,3 +48,5 @@ void EditorWidget::clear()
 {
     editor()->clear();
 }
+
+#include "moc_editorwidget.cpp"
